toaster_pro library

ToasterPro — a premium overlay-based toast notification library for Flutter.

Usage:

ToasterPro.show(title: 'Success', message: 'Done!', type: ToastType.success);

Classes

DelightToastBar
Core class for showing overlay-based toast notifications.
ToastCard
A rich toast card widget for use inside DelightToastBar.
ToasterPro
High-level convenience API for showing toasts from anywhere in the app.

Enums

DelightSnackbarPosition
Position of the toast notification
ToastType
Visual type of the toast